Octave and MATLAB
=================


Our backend JOBE server supports Octave, so any MATLAB programs that also run in Octave, which should be most of them are supported.

.. activecode:: octave1
    :language: octave

    x = 2 + 2
    printf("%d\n", x)
